/***************************************************************************
                          rintro.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

/****************************************************************************
** rintro.h 1998/10/04 A. Mustun RibbonSoft 
**
** Copyright (C) 1998 RibbonSoft.  All rights reserved.
**
*****************************************************************************/

#ifndef RINTRO_H
#define RINTRO_H

#include <qwidget.h>

class QLabel;
class QPixmap;

class RIntro : public QWidget
{
  Q_OBJECT
public:
  RIntro(const QString& _version,
         QWidget* _parent=0, 
         const char* _name=0);
  ~RIntro();

private:
  QString    sVersion;
  QPixmap*   pIntro;

protected:
  virtual void paintEvent(QPaintEvent* _ev);
  
};


#endif

// EOF



